# エラーが発生しました

新しいアイテムを作成する過程でエラーが発生しました。

- OpenSesameの古いバージョンで作成されたプラグインを使用している可能性があります。
- これらの警告はバグレポート("予期しないエラー")を引き起こすかもしれません: バグレポートは拡張機能 `bug_report` を無効にすることで非表示にできます。
- 詳細な情報はデバッグウィンドウに出力されています。
